@@ -11,7 +11,13 @@ from .usage import usage
 
 def get_target(name=None, dest=None):
     name = name or environ.get('setux_target')
-    dest = dest or environ.get('setux_outdir', expanduser('~/setux'))
+    if not dest:
+        dest = environ.get('setux_outdir')
+        if dest:
+            user = environ.get('USER')
+            dest = f'{dest}/{user}'
+        else:
+            dest = expanduser('~/setux')
     if name:
         target = SSH(name=name, host=name, outdir=dest)
         if not target.cnx:
@@ -45,6 +51,7 @@ def main():
         if name in target.modules.items:
             try:
                 k = dict(i.split('=') for i in args)
+                if name=='infos': k['report'] = 'quiet'
                 try:
                     target.deploy(name, **k)
                 except KeyError as x:
