@@ -1,3 +1,4 @@
+from setux.core.manage import Manager
 from setux.core.package import CommonPackager
 
 
@@ -7,10 +8,11 @@ def run(target, arg):
 def module(target, arg):
     mod = target.modules.items.get(arg)
     if mod:
+        hlp = mod.help()
         title = f'module {arg}'
         print(title)
         print('-'*len(title))
-        print(mod.help())
+        print(hlp)
     else:
         print(f' ! unkown module ! {arg}')
 
@@ -41,20 +43,21 @@ def manage(target, line):
 def manager(target, arg):
     manager = target.managers.items.get(arg)
     if manager:
+        hlp = manager.help()
         title = f'manager {arg}'
         print(title)
         print('-'*len(title))
-        print(manager.help())
+        print(hlp)
     else:
         print(f' ! unkown manager ! {arg}')
 
 def managers(target, arg):
-    managers = target.managers.items
+    managers = target.managers
     print('managers')
     print('-------')
     width = len(max(managers.keys(), key=len))+4
-    for name, mod in sorted(managers.items()):
-        hlp = mod.help()
+    for name, manager in sorted(managers.items()):
+        hlp = manager.help()
         first = hlp.split('\n')[0]
         if (
             not arg
@@ -71,8 +74,8 @@ def mappings(target, arg):
         for name, pkg in sorted(packages.items()):
             print(f'{name:>{width}} {pkg}')
 
-    for manager in target.managers:
-        if issubclass(manager, CommonPackager) and manager.is_supported(target.distro):
+    for manager in target.managers.values():
+        if isinstance(manager, CommonPackager):
             packages = manager.pkgmap
             if packages:
                 print(f'{manager.manager} :')
@@ -90,7 +93,8 @@ def mappings(target, arg):
             print(f'{name:>{width}} {svc}')
 
 def deploy(target, arg):
-    target.deploy(arg)
+    report = 'quiet' if arg=='infos' else 'normal'
+    target.deploy(arg, report=report)
 
 def remote(target, arg):
     target.remote(arg)
@@ -110,7 +114,7 @@ def installable(target, arg):
     print('\n'.join(f'{n} {v}' for n, v in pkg))
 
 def search(target, arg):
-    found = target.search(arg)
+    found = target.search(arg, report='quiet')
     print('\n'.join(f'{p} {n} {v}' for p, n, v in found))
 
 def bigs(target, arg):
