@@ -50,7 +50,7 @@ class Repl(Cmd):
         for name, cmd in commands.items():
             setattr(self, f'do_{name}', safe(cmd, target))
         self.modules = target.modules.items.keys()
-        self.managers = target.managers.items.keys()
+        self.managers = target.managers.keys()
         super().__init__()
 
     def do_help(self, cmd):
